@@ -112,6 +112,8 @@ namespace rpp {
   class Environment;
 }
 
+class CppPreprocessEnvironment;
+
 namespace Cpp {
 
 struct MacroSetRepository : public Utils::BasicSetRepository {
@@ -230,8 +232,14 @@ class KDEVCPPDUCHAIN_EXPORT EnvironmentFile : public KDevelop::ParsingEnvironmen
     ///Returns the set of all strings that can affect this file from outside.
     const ReferenceCountedStringSet& strings() const;
     
-    //The parameter should be a EnvironmentFile that was lexed AFTER the content of this file
-    void merge( const EnvironmentFile& file );
+    ///The parameter should be a EnvironmentFile that was processed AFTER the content of this file
+    ///@param file The file to merge
+    ///@param env Optionally, the current environment that is active _before_ the
+    ///           included file is "virtually" processed.
+    ///@warning The file must _not_ be merged yet into the environment when this is called. Also,
+    ///         after merging the environment-files a file cannot be merged into the environment any more,
+    ///         so this should only be used indirectly through CppPreprocessEnvironment::merge
+    void merge( const EnvironmentFile& file, CppPreprocessEnvironment* env = 0 );
 
     bool operator <  ( const EnvironmentFile& rhs ) const {
       return url() < rhs.url();
