@@ -1,4 +1,6 @@
 /*
+   Copyright 2009 Ramón Zarazúa <killerfox512+kde@gmail.com>
+   
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.
@@ -95,7 +97,7 @@ public:
     //Represents the whole code of the manipulated top-context for reading.
     //Changes should be done as transactions to m_changeSet.
     ///@warning This must be checked for zero before using. It is zero if the file could not be read.
-    const KDevelop::CodeRepresentation* m_codeRepresentation;
+    const KDevelop::CodeRepresentation::Ptr m_codeRepresentation;
 };
 }
 
