@@ -210,7 +210,8 @@ KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size
   ADD_TOKEN(while);
   ADD_TOKEN(xor);
   ADD_TOKEN(xor_eq);
-  ADD_TOKEN(__qt_sig_slot__);
+  ADD_TOKEN(__qt_signal__);
+  ADD_TOKEN(__qt_slot__);
   return ret;
 }
 
