@@ -353,6 +353,10 @@ void pp_macro_expander::operator()(Stream& input, Stream& output)
             int start = input.offset();
             
             skip_blanks(input, devnull());
+            if (input.atEnd()) {
+              // this might happen in e.g. /usr/include/bits/mathcalls.h
+              continue;
+            }
             //Omit paste tokens behind empty used actuals, else we will merge with the previous text
             if(input == '#' && (++input) == '#') {
               ++input;
@@ -378,9 +382,9 @@ void pp_macro_expander::operator()(Stream& input, Stream& output)
           else if (name == fileIndex)
             output.appendString(inputPosition, convertFromByteArray(QString("\"%1\"").arg(m_engine->currentFileNameString()).toUtf8()));
           else if (name == dateIndex)
-            output.appendString(inputPosition, convertFromByteArray(QDate::currentDate().toString("MMM dd yyyy").toUtf8()));
+            output.appendString(inputPosition, convertFromByteArray(QDate::currentDate().toString("\"MMM dd yyyy\"").toUtf8()));
           else if (name == timeIndex)
-            output.appendString(inputPosition, convertFromByteArray(QTime::currentTime().toString("hh:mm:ss").toUtf8()));
+            output.appendString(inputPosition, convertFromByteArray(QTime::currentTime().toString("\"hh:mm:ss\"").toUtf8()));
           else
             output.appendString(inputPosition, name);
           continue;
