@@ -42,8 +42,6 @@ CMakeBuildDirChooser::CMakeBuildDirChooser(QWidget* parent)
 
     QString cmakeBin=KStandardDirs::findExe( "cmake" );
     setCMakeBinary(KUrl(cmakeBin));
-    // Default to debug builds in kdevelop
-    setBuildType("Debug");
     
     connect(m_chooserUi->cmakeBin, SIGNAL(textChanged(const QString &)), this, SLOT(updated()));
     connect(m_chooserUi->buildFolder, SIGNAL(textChanged(const QString &)), this, SLOT(updated()));
@@ -200,8 +198,9 @@ void CMakeBuildDirChooser::setBuildFolder(const KUrl& url)
 }
 
 void CMakeBuildDirChooser::setBuildType(const QString& s) 
-{ 
-    m_chooserUi->buildType->addItem(s); 
+{
+    m_chooserUi->buildType->addItem(s);
+    m_chooserUi->buildType->setCurrentIndex(m_chooserUi->buildType->findText(s));
     updated();
 }
 
