@@ -43,28 +43,23 @@ class KDEVCMAKECOMMON_EXPORT CMakeAst /*Should considerate making it abstract. *
         * Writes the information stored in the Ast into the @p buffer.
         * All Asts that are a child of this Ast are written back as well.
         */
-        virtual void writeBack(QString& buffer) const;
-        
         virtual bool isDeprecated() const { return false; }
     
-        virtual bool parseFunctionInfo( const CMakeFunctionDesc& ) { return false; }
+        virtual bool parseFunctionInfo( const CMakeFunctionDesc& )=0;
     
         int line() const { return m_line; }
         const CMakeFileContent & content() const { return m_content; }
         void setContent(const CMakeFileContent &cont, int nline=0) { m_content=cont; m_line=nline; }
         const QList<CMakeFunctionArgument> & outputArguments() const { return m_outputArguments; }
-        QStringList errors() const { return m_errors; }
     private:
-        CMakeAst( const CMakeAst&  ) /*: m_children( ast.m_children )*/ {}
+        CMakeAst( const CMakeAst&  ) {}
         
         QList<CMakeFunctionArgument> m_outputArguments;
+        CMakeFileContent m_content;
+
+        int m_line;
     protected:
         void addOutputArgument(const CMakeFunctionArgument& arg) { m_outputArguments.append(arg); }
-
-        CMakeFileContent m_content;
-        int m_line;
-        QStringList m_errors;
-
 };
 
 #define CMAKE_REGISTER_AST( klassName, astId ) namespace {                 \
@@ -76,10 +71,8 @@ class KDEVCMAKECOMMON_EXPORT CMakeAst /*Should considerate making it abstract. *
         klassName();                                         \
        ~klassName();                                         \
                                                              \
-        virtual void writeBack( QString& buffer ) const;           \
         virtual int accept(CMakeAstVisitor * visitor) const { return visitor->visit(this); } \
-        virtual bool parseFunctionInfo( const CMakeFunctionDesc& ); \
-        QList<CMakeFunctionArgument> outputArguments;
+        virtual bool parseFunctionInfo( const CMakeFunctionDesc& );
 
 #define CMAKE_ADD_AST_MEMBER( returnType, returnName )             \
     public:                                                         \
@@ -87,10 +80,6 @@ class KDEVCMAKECOMMON_EXPORT CMakeAst /*Should considerate making it abstract. *
     private:                                                        \
         returnType m_##returnName;
 
-#define CMAKE_ADD_AST_FUNCTION( function ) \
-    public:                                \
-       function;
-
 #define CMAKE_MARK_AS_DEPRECATED() virtual bool isDeprecated() const { return true; }
 
 #define CMAKE_END_AST_CLASS( klassName ) };
@@ -150,13 +139,13 @@ CMAKE_ADD_AST_MEMBER( QStringList, sourceLists )
 CMAKE_END_AST_CLASS( AddExecutableAst )
 
 CMAKE_BEGIN_AST_CLASS( AddLibraryAst )
+enum LibraryType {Shared, Static, Module, Unknown};
 CMAKE_ADD_AST_MEMBER( QString, libraryName )
-CMAKE_ADD_AST_MEMBER( bool, isShared )
-CMAKE_ADD_AST_MEMBER( bool, isStatic )
-CMAKE_ADD_AST_MEMBER( bool, isModule )
+CMAKE_ADD_AST_MEMBER( LibraryType, type )
 CMAKE_ADD_AST_MEMBER( bool, isImported )
 CMAKE_ADD_AST_MEMBER( bool, excludeFromAll )
 CMAKE_ADD_AST_MEMBER( QStringList, sourceLists )
+static QMap<QString, LibraryType> s_typeForName;
 CMAKE_END_AST_CLASS( AddLibraryAst )
 
 CMAKE_BEGIN_AST_CLASS( AddSubdirectoryAst )
@@ -259,8 +248,8 @@ CMAKE_END_AST_CLASS( ExportLibraryDepsAst )
 
 
 CMAKE_BEGIN_AST_CLASS( FileAst )
-enum TypeFile { WRITE, APPEND, READ, GLOB, GLOB_RECURSE, REMOVE, REMOVE_RECURSE,
-            MAKE_DIRECTORY, RELATIVE_PATH, TO_CMAKE_PATH, TO_NATIVE_PATH, STRINGS, DOWNLOAD };
+enum TypeFile { Write, Append, Read, Glob, GlobRecurse, Remove, RemoveRecurse,
+            MakeDirectory, RelativePath, ToCmakePath, ToNativePath, Strings, Download };
 CMAKE_ADD_AST_MEMBER( TypeFile, type )
 CMAKE_ADD_AST_MEMBER( QString, path )
 CMAKE_ADD_AST_MEMBER( QString, variable )
@@ -370,7 +359,7 @@ CMAKE_END_AST_CLASS( ForeachAst )
 
 
 CMAKE_BEGIN_AST_CLASS( GetCMakePropertyAst )
-        enum PropertyType { VARIABLES, CACHE_VARIABLES, COMMANDS, MACROS };
+        enum PropertyType { Variables, CacheVariables, Commands, Macros };
 CMAKE_ADD_AST_MEMBER( PropertyType, type )
 CMAKE_ADD_AST_MEMBER( QString, variableName )
 CMAKE_END_AST_CLASS( GetCMakePropertyAst )
@@ -391,7 +380,7 @@ CMAKE_ADD_AST_MEMBER( QString, outputVariable )
 CMAKE_ADD_AST_MEMBER( QString, typeName )
 CMAKE_ADD_AST_MEMBER( QString, name )
 
-enum Behaviour { None, SET, DEFINED, BRIEF_DOCS, FULL_DOCS };
+enum Behaviour { None, Set, Defined, BriefDocs, FullDocs };
 CMAKE_ADD_AST_MEMBER( Behaviour, behaviour )
 CMAKE_END_AST_CLASS( GetPropertyAst )
 
@@ -404,7 +393,7 @@ CMAKE_END_AST_CLASS( GetDirPropertyAst )
 
 
 CMAKE_BEGIN_AST_CLASS( GetFilenameComponentAst )
-        enum ComponentType { PATH, ABSOLUTE, NAME, EXT, NAME_WE, PROGRAM };
+        enum ComponentType { Path, Absolute, Name, Ext, NameWe, Program };
 CMAKE_ADD_AST_MEMBER( QString, variableName )
 CMAKE_ADD_AST_MEMBER( QString, fileName )
 CMAKE_ADD_AST_MEMBER( ComponentType, type )
@@ -448,7 +437,7 @@ CMAKE_END_AST_CLASS( IncludeAst )
 
 
 CMAKE_BEGIN_AST_CLASS( IncludeDirectoriesAst )
-        enum IncludeType { DEFAULT=0, AFTER, BEFORE };
+        enum IncludeType { Default=0, After, Before };
 CMAKE_ADD_AST_MEMBER( IncludeType, includeType )
 CMAKE_ADD_AST_MEMBER( bool, isSystem )
 CMAKE_ADD_AST_MEMBER( QStringList, includedDirectories )
@@ -524,7 +513,7 @@ CMAKE_END_AST_CLASS( LinkLibrariesAst )
 
 
 CMAKE_BEGIN_AST_CLASS( ListAst )
-    enum ListType { LENGTH, GET, APPEND, FIND, INSERT, REMOVE_ITEM, REMOVE_AT, SORT, REVERSE };
+    enum ListType { Length, Get, Append, Find, Insert, RemoveItem, RemoveAt, Sort, Reverse };
     CMAKE_ADD_AST_MEMBER( ListType, type )
     CMAKE_ADD_AST_MEMBER( QString, list )
     CMAKE_ADD_AST_MEMBER( QString, output )
@@ -575,7 +564,7 @@ CMAKE_END_AST_CLASS( MathAst )
 
 
 CMAKE_BEGIN_AST_CLASS( MessageAst )
-enum MessageType { SEND_ERROR, STATUS, FATAL_ERROR };
+enum MessageType { SendError, Status, FatalError };
 CMAKE_ADD_AST_MEMBER( MessageType, type )
 CMAKE_ADD_AST_MEMBER( QStringList, message )
 CMAKE_END_AST_CLASS( MessageAst )
@@ -678,9 +667,9 @@ CMAKE_END_AST_CLASS( SourceGroupAst )
 
 
 CMAKE_BEGIN_AST_CLASS( StringAst )
-enum StringAstType { REGEX, REPLACE, COMPARE, ASCII, CONFIGURE,
-    TOUPPER, TOLOWER, LENGTH, SUBSTRING, STRIP, RANDOM };
-enum CommandType { MATCH, MATCHALL, REGEX_REPLACE, EQUAL, NOTEQUAL, LESS, GREATER };
+enum StringAstType { Regex, Replace, Compare, Ascii, Configure,
+    ToUpper, ToLower, Length, Substring, Strip, Random };
+enum CommandType { Match, MatchAll, RegexReplace, Equal, NotEqual, Less, Greater };
 CMAKE_ADD_AST_MEMBER( StringAstType, type )
 CMAKE_ADD_AST_MEMBER( CommandType, cmdType )
 CMAKE_ADD_AST_MEMBER( QString, outputVariable )
@@ -802,7 +791,7 @@ CMAKE_BEGIN_AST_CLASS( BreakAst )
 CMAKE_END_AST_CLASS( BreakAst )
 
 CMAKE_BEGIN_AST_CLASS( CMakePolicyAst )
-enum Action { VERSION, SET, PUSH, POP };
+enum Action { Version, Set, Push, Pop };
 CMAKE_ADD_AST_MEMBER( Action, action )
 //VERSION
 CMAKE_ADD_AST_MEMBER( QList<int>, version )
